%define		sname turnserver

# We don't yet ship libmongoc
#bcond_with	build_mongodb
%bcond_with	build_redis

Name:		coturn
Version:	4.5.2
Release:	%mkrel 3
Group:		System/Servers
License:	BSD
Summary:	Free open source implementation of TURN and STUN Server
URL:		http://coturn.github.io
Source:		https://github.com/%{name}/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(openssl) >= 1.0.2
BuildRequires:	pkgconfig(libevent) >= 2.0
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	sqlite3-tools
BuildRequires:	pkgconfig(libpq)
BuildRequires:	mysql-devel
#if with build_mongodb
#BuildRequires:	pkgconfig(mongoc)
#endif
%if %with build_redis
BuildRequires:	pkgconfig(hiredis)
%endif

%description
The TURN Server is a VoIP media traffic NAT traversal server and gateway.
It can be used as a general-purpose network traffic TURN server and gateway, too.

%prep
%setup -q
%autopatch -p1

%build

# We don't like the way the docs, schemas and examples are packaged
# So we let them be installed and then remove them
%configure \
    -confdir=%{_sysconfdir}/%{sname} \
    -turndbdir=%{_localstatedir}/db \
    -docsdir=%{_datadir}/%{name}/doc \
    -examplesdir=%{_datadir}/%{name}/examples \
    -schemadir=%{_datadir}/%{name}/schema \
    -mandir=%{_datadir}

%make_build
%make_build sqlite/turndb

%check
%make_build check

%install

%make_install

# Is the client library really needed outside coturn?
rm -rf %{buildroot}%{_includedir}/turn
rm -f %{buildroot}%{_libdir}/libturnclient.a

# Remove docs, examples and schemas installed by Makefile
rm -rf %{buildroot}/%{_datadir}/%{name}
mv postinstall.txt README.urpmi

mv %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf.default %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf
install -D -p -m 0644 rpm/%{sname}.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/%{sname}
install -d %{buildroot}%{_localstatedir}/run/%{sname}
install -D -p -m 0644 rpm/%{sname}-tmpfiles.conf %{buildroot}%{_tmpfilesdir}/%{sname}.conf

# Revert to forking to avoid start timeout
# TODO: change back when fixed, see https://github.com/coturn/coturn/issues/118
sed -i -e 's!Type=notify!Type=exec\nPIDFile=/run/turnserver/turnserver.pid!' \
	-e 's!/var/run/turnserver/turnserver.pid!/run/turnserver/turnserver.pid!' \
	rpm/%{sname}.service.fc

install -D -p -m 0644 rpm/%{sname}.service.fc %{buildroot}%{_unitdir}/%{sname}.service

sed -i -e "s/#syslog/syslog/g" \
    -e "s/#no-stdout-log/no-stdout-log/g" \
    %{buildroot}/%{_sysconfdir}/%{sname}/%{sname}.conf

sed -i -e "s/#pidfile/pidfile/g" \
    -e "s:/var/run/turnserver.pid:/run/turnserver/turnserver.pid:g" \
    %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf

%pre
%_pre_useradd %{sname} /var/run/%{sname} /bin/sh
%_pre_groupadd %{sname} %{sname}

%preun
%_preun_service %{sname}

%post
%_tmpfilescreate %{sname}
%_post_service %{sname}

%postun
%_postun_userdel %{sname}
%_postun_groupdel %{sname}

%files
%doc turndb examples/etc examples/scripts
%doc AUTHORS ChangeLog INSTALL LICENSE NOTE README.* STATUS TODO
%dir %attr(0755,root,turnserver) %{_sysconfdir}/%{sname}
%attr(0640,root,turnserver) %config(noreplace) %{_sysconfdir}/%{sname}/%{sname}.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{sname}
%{_unitdir}/%{sname}.service
%{_tmpfilesdir}/%{sname}.conf
%{_bindir}/turnadmin
%{_bindir}/turnserver
%{_bindir}/turnutils_peer
%{_bindir}/turnutils_stunclient
%{_bindir}/turnutils_uclient
%{_bindir}/turnutils_oauth
%{_bindir}/turnutils_natdiscovery
%attr(0640,turnserver,turnserver) %{_localstatedir}/db/turndb
%{_mandir}/man1/*


%changelog
* Thu Sep 02 2021 rapsys <rapsys> 4.5.2-3.mga8
+ Revision: 1744006
- Fix pid path
  Fix service type to allow start
  Fix perms

* Tue Jan 12 2021 tmb <tmb> 4.5.2-2.mga8
+ Revision: 1671396
- bump rel for mga7 upgrade path

* Tue Jan 12 2021 neoclust <neoclust> 4.5.2-1.mga8
+ Revision: 1671390
- New version 4.5.2 (mga#28068)

* Tue Jul 07 2020 ns80 <ns80> 4.5.1.3-1.mga8
+ Revision: 1602795
- new version 4.5.1.3 for CVE-2020-4067 (mga#26879)

* Wed May 13 2020 shlomif <shlomif> 4.5.1.2-1.mga8
+ Revision: 1583589
- New version 4.5.1.2 by cheese-e-boi: MGA#26413

* Sun Feb 16 2020 daviddavid <daviddavid> 4.5.1.1-2.mga8
+ Revision: 1531995
- rebuild for new libevent 2.1.11

* Thu Feb 13 2020 pterjan <pterjan> 4.5.1.1-1.mga8
+ Revision: 1513526
- Update to 4.5.1.1, this contains alignment fixes that should fix tests on arm

* Wed Feb 12 2020 umeabot <umeabot> 4.5.0.7-3.mga8
+ Revision: 1511469
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 4.5.0.7-2.mga7
+ Revision: 1296824
- Mageia 7 Mass Rebuild

* Wed May 16 2018 mitya <mitya> 4.5.0.7-1.mga7
+ Revision: 1229847
- New version 4.5.0.7

* Sat Dec 23 2017 wally <wally> 4.5.0.6-3.mga7
+ Revision: 1184224
- rebuild for new mariadb

* Sat Sep 09 2017 cjw <cjw> 4.5.0.6-2.mga7
+ Revision: 1152164
- rebuild for openssl 1.1

* Sat May 20 2017 mitya <mitya> 4.5.0.6-1.mga6
+ Revision: 1103479
- New version 4.5.0.6

* Sun Feb 12 2017 mrambo3501 <mrambo3501> 4.5.0.4-2.mga6
+ Revision: 1085896
- rebuild for new libevent

* Sat Nov 12 2016 mitya <mitya> 4.5.0.4-1.mga6
+ Revision: 1066621
- Initial import
- Created package structure for 'coturn'.

